@@ -37,6 +37,6 @@ class Users:
         return User(json.loads(response.read()))
 
     @staticmethod
-    def UserCanManageAsset(id, assetId):
+    def CanManage(id, assetId):
         response = urllib.request.urlopen("http://api.roblox.com/users/" + str(id) + "/canmanage/" + str(assetId))
         return json.loads(response.read())["CanManage"]
